@@ -65,7 +65,7 @@ PROSPECTOR_BLACKLIST = [
     "Redefining built-in 'reduce'",  # allow importing reduce from functools, required for Python 3 compatibility
     'c-extension-no-member', # run-time inspection of c extensions is disabled by default and gives warnings
 ]
-# to dissable any of these warnings in a block, you can do things like add a comment # pylint: disable=C0321
+# to disable any of these warnings in a block, you can do things like add a comment # pylint: disable=C0321
 PROSPECTOR_WHITELIST = [
     #'protected-access',
     'E101',  # mixing tabs and spaces
@@ -80,6 +80,7 @@ PROSPECTOR_WHITELIST = [
     'bad-indentation',
     'bad-whitespace',
     'bare-except',
+    'consider-using-with', # By using 'with' the release of the allocated res is ensured in the case of an exception.
     'dangerous-default-value',
     'duplicate-key',  # when a key appears twice in a dict definition
     'import-star-module-level',  # Import * only allowed at module level
@@ -230,10 +231,11 @@ def check_autogenerated_ci_config_file(testcase_instance, ci_cfg_fn, expected_co
         testcase_instance.assertNotEqual(current_contents, expected_contents, error_msg)
 
         # if the ignore file exists, it should contain the URL of a vsc-install issue
-        txt = open(ci_cfg_ignore_fn).read()
-        regex = re.compile(r'https://github.com/hpcugent/vsc-install/issues/[0-9]+')
-        error_msg = "Pattern '%s' does not match in contents of %s: %s" % (regex.pattern, ci_cfg_ignore_fn, txt)
-        testcase_instance.assertTrue(bool(regex.search(txt)), error_msg)
+        with open(ci_cfg_ignore_fn) as ignore_file:
+            txt = ignore_file.read()
+            regex = re.compile(r'https://github.com/hpcugent/vsc-install/issues/[0-9]+')
+            error_msg = "Pattern '%s' does not match in contents of %s: %s" % (regex.pattern, ci_cfg_ignore_fn, txt)
+            testcase_instance.assertTrue(bool(regex.search(txt)), error_msg)
     else:
         error_msg = "Contents of %s does not match expected contents, " % ci_cfg_fn
         error_msg += "you should run 'python -m vsc.install.ci' again to re-generate %s" % ci_cfg_fn
